local folder, core = ...

--Globals
local pairs = pairs

-- Isolate the environment
--~ setfenv(1, core)
-- local

local defaultSettings = core.defaultSettings

local P = {}
local prev_OnEnable = core.OnEnable;
function core:OnEnable()
	prev_OnEnable(self);
	
--~ 	self:Debug("OnEnable", "options", self.db.profile)
	P = self.db.profile
end



local CoreOptionsTable = {
	name = core.titleFull,
	type = "group",
	childGroups = "tab",

	args = {
		core={
			name = "Core",
			type = "group",
			order = 1,
			args={}
		},

		who={
			name = "Who",
			type = "group",
			order = 2,
			args={}
		},
		
		bar = {
			name = "Bar",
			type = "group",
			order = 3,
			args={}
		},
	},
}

-- CORE TAB
CoreOptionsTable.args.core.args.enable = {
	type = "toggle",	order	= 1,
	name	= "Enable",
	desc	= "Enables / Disables the addon",
	set = function(info,val) 
		if val == true then
			core:Enable()
		else
			core:Disable()
		end
	end,
	get = function(info) return core:IsEnabled() end
}



defaultSettings.profile.defaultSpells		= 1
CoreOptionsTable.args.core.args.defaultSpells = {
	name = "Show by default",
	order = 10,
	desc = "spells to show by default",
	type = "select",
	
	values = function()
		return {
			"All", 
			"Mine Only",
			"None",
		}
	end,
	set = function(info,val) 
		P.defaultSpells = val
	end,
	get = function(info) return P.defaultSpells end
}



defaultSettings.profile.unknownSpellDataIcon		= true
CoreOptionsTable.args.core.args.unknownSpellDataIcon = {
	name = "Unknown spells icon",
	desc = "Display a question mark above plates we don't know spells for. Target or mouseover those plates.",
	type = "toggle",
	order	= 11,
	set = function(info,val) 
		P.unknownSpellDataIcon = val
	end,
	get = function(info) return P.unknownSpellDataIcon end
}

defaultSettings.profile.showBuffs		= true
CoreOptionsTable.args.core.args.showBuffs = {
	name = "Show Buffs",
	desc = "buffs",
	type = "toggle",
	order	= 12,
	set = function(info,val) 
		P.showBuffs = val
	end,
	get = function(info) return P.showBuffs end
}

defaultSettings.profile.showDefuffs		= true
CoreOptionsTable.args.core.args.showDefuffs = {
	name = "Show Debuffs",
	desc = "debuffs",
	type = "toggle",
	order	= 13,
	set = function(info,val) 
		P.showDefuffs = val
	end,
	get = function(info) return P.showDefuffs end
}

defaultSettings.profile.showAura		= false
CoreOptionsTable.args.core.args.showAura = {
	name = "Show Aura",
	desc = "auras",
	type = "toggle",
	order	= 14,
	set = function(info,val) 
		P.showAura = val
	end,
	get = function(info) return P.showAura end
}

--~ defaultSettings.profile.copyPlateAlpha		= true
--~ CoreOptionsTable.args.core.args.copyPlateAlpha = {
--~ 	name = "Copy Plate Alpha",
--~ 	desc = "Set buff frame's transparentcy to the same of the plate it's on.",
--~ 	type = "toggle",
--~ 	order	= 12,
--~ 	set = function(info,val) 
--~ 		P.copyPlateAlpha = val
--~ 	end,
--~ 	get = function(info) return P.copyPlateAlpha end
--~ }

--~ defaultSettings.profile.copyPlateScale		= true
--~ CoreOptionsTable.args.core.args.copyPlateScale = {
--~ 	name = "Copy Plate Scale",
--~ 	desc = "Set buff frame's scale (size) to the same of the plate it's on.",
--~ 	type = "toggle",
--~ 	order	= 13,
--~ 	set = function(info,val) 
--~ 		P.copyPlateScale = val
--~ 	end,
--~ 	get = function(info) return P.copyPlateScale end
--~ }

--END CORE TAB

--   WHO TAB
CoreOptionsTable.args.who.args.typeHeader = {
	name	= "Type",
	order	= 10,
	type = "header",
}

defaultSettings.profile.abovePlayers		= true
CoreOptionsTable.args.who.args.abovePlayers = {
	name = "Players",
	desc = "Add buffs above players",
	type = "toggle",
	order	= 11,
	set = function(info,val) 
		P.abovePlayers = val
	end,
	get = function(info) return P.abovePlayers end
}

defaultSettings.profile.aboveNPC		= true
CoreOptionsTable.args.who.args.aboveNPC = {
	name = "NPC",
	desc = "Add buffs above NPCs",
	type = "toggle",
	order	= 12,
	set = function(info,val) 
		P.aboveNPC = val
	end,
	get = function(info) return P.aboveNPC end
}

CoreOptionsTable.args.who.args.reactionHeader = {
	name	= "Reaction",
	order	= 15,
	type = "header",
}

defaultSettings.profile.aboveFriendly		= true
CoreOptionsTable.args.who.args.aboveFriendly = {
	name = "Friendly",
	desc = "Add buffs above friendly plates",
	type = "toggle",
	order	= 16,
	set = function(info,val) 
		P.aboveFriendly = val
	end,
	get = function(info) return P.aboveFriendly end
}

defaultSettings.profile.aboveNeutral		= true
CoreOptionsTable.args.who.args.aboveNeutral = {
	name = "Neutral",
	desc = "Add buffs above neutral plates",
	type = "toggle",
	order	= 17,
	set = function(info,val) 
		P.aboveNeutral = val
	end,
	get = function(info) return P.aboveNeutral end
}

defaultSettings.profile.aboveHostile		= true
CoreOptionsTable.args.who.args.aboveHostile = {
	name = "Hostile",
	desc = "Add buffs above hostile plates",
	type = "toggle",
	order	= 18,
	set = function(info,val) 
		P.aboveHostile = val
	end,
	get = function(info) return P.aboveHostile end
}

--   END WHO TAB

defaultSettings.profile.barAnchorPoint		= "BOTTOM"
CoreOptionsTable.args.bar.args.barAnchorPoint = {
	name = "Bar Anchor Point",
	order = 1,
	desc = "Point of the buff frame that gets anchored to the nameplate.\ndefault=Bottom",
	type = "select",
	
	values = function()
		return {
			["TOP"]="Top", 
			["BOTTOM"]="Bottom", 
			["LEFT"]="Left", 
			["RIGHT"]="Right", 
			["CENTER"]="Center", 
			["TOPLEFT"]="Top Left", 
			["BOTTOMLEFT"]="Bottom Left", 
			["TOPRIGHT"]="Top Right", 
			["BOTTOMRIGHT"]="Bottom Right", 
		}
	end,
	set = function(info,val) 
		P.barAnchorPoint = val
		core:ResetAllBarPoints()
	end,
	get = function(info) return P.barAnchorPoint end
}

defaultSettings.profile.plateAnchorPoint		= "TOP"
CoreOptionsTable.args.bar.args.plateAnchorPoint = {
	name = "Plate Anchor Point",
	order = 2,
	desc = "Point of the nameplate our buff frame gets anchored to.\ndefault=Top",
	type = "select",
	
	values = function()
		return {
			["TOP"]="Top", 
			["BOTTOM"]="Bottom", 
			["LEFT"]="Left", 
			["RIGHT"]="Right", 
			["CENTER"]="Center", 
			["TOPLEFT"]="Top Left", 
			["BOTTOMLEFT"]="Bottom Left", 
			["TOPRIGHT"]="Top Right", 
			["BOTTOMRIGHT"]="Bottom Right", 
		}
	end,
	set = function(info,val) 
		P.plateAnchorPoint = val
		core:ResetAllBarPoints()
	end,
	get = function(info) return P.plateAnchorPoint end
}

defaultSettings.profile.barOffsetX		= 0
CoreOptionsTable.args.bar.args.barOffsetX = {
	name = "Bar X Offset",
	desc = "Left to right offset.",
	type = "range",
	order	= 5,
	min		= -100,
	max		= 100,
	step	= 1,
	set = function(info,val) 
		P.barOffsetX = val
		core:ResetAllBarPoints()
	end,
	get = function(info) return P.barOffsetX end
}

defaultSettings.profile.barOffsetY		= 8 --bit north incase user's running Threat plates.
CoreOptionsTable.args.bar.args.barOffsetY = {
	name = "Bar Y Offset",
	desc = "Up to down offset.",
	type = "range",
	order	= 6,
	min		= -100,
	max		= 100,
	step	= 1,
	set = function(info,val) 
		P.barOffsetY = val
		core:ResetAllBarPoints()
	end,
	get = function(info) return P.barOffsetY end
}

defaultSettings.profile.iconsPerRow		= 6
CoreOptionsTable.args.bar.args.iconsPerRow = {
	name = "Icons Per Row",
	desc = "x",
	type = "range",
	order	= 7,
	min		= 1,
	max		= 16,
	step	= 1,
	set = function(info,val) 
		P.iconsPerRow = val
		core:ResetAllPlateIcons()
		core:UpdateBarsSize()
		core:ShowAllKnownSpells()
	end,
	get = function(info) return P.iconsPerRow end
}

defaultSettings.profile.rowGroth		= 1
CoreOptionsTable.args.bar.args.rowGroth = {
	name = "Row Growth",
	order = 8,
	desc = "Which way do the rows grow, up or down.",
	type = "select",
	
	values = function()
		return {
			"Up",
			"Down",
		}
	end,
	set = function(info,val) 
		P.rowGroth = val
--~ 		core:ResetAllPlateIcons()
		core:ResetAllBarPoints()
	end,
	get = function(info) return P.rowGroth end
}

defaultSettings.profile.numRows		= 2
CoreOptionsTable.args.bar.args.numRows = {
	name = "Max num or rows to show.",
	desc = "x",
	type = "range",
	order	= 9,
	min		= 1,
	max		= 4,
	step	= 1,
	set = function(info,val) 
		P.numRows = val
		core:ResetAllPlateIcons()
		core:UpdateBarsSize()
		core:UpdateBarsBackground()
	end,
	get = function(info) return P.numRows end
}


defaultSettings.profile.iconSize		= 20
CoreOptionsTable.args.bar.args.iconSize = {
	name = "Icon Size",
	desc = "Size of the icons.",
	type = "range",
	order	= 10,
	min		= 16,
	max		= 60,
	step	= 4,
	set = function(info,val) 
		P.iconSize = val
		core:ResetIconSizes()
		core:UpdateBarsSize()
	end,
	get = function(info) return P.iconSize end
}

defaultSettings.profile.biggerSelfSpells		= true
CoreOptionsTable.args.bar.args.biggerSelfSpells = {
	name = "Bigger self spells",
	desc = "Make your spells 20% bigger then other's.",
	type = "toggle",
	order	= 11,
	set = function(info,val) 
		P.biggerSelfSpells = val
	end,
	get = function(info) return P.biggerSelfSpells end
}

defaultSettings.profile.showCooldown		= true
CoreOptionsTable.args.bar.args.showCooldown = {
	name = "Show cooldown",
	desc = "Show cooldown text",
	type = "toggle",
	order	= 12,
	set = function(info,val) 
		P.showCooldown = val
--~ 		core:ResetCooldownSize()
--~ 		core:ResetAllPlateIcons()
		core:ResetIconSizes()--Adjust the frame height with the new cooldown size
		core:UpdateBarsSize()
		core:ShowAllKnownSpells()
	end,
	get = function(info) return P.showCooldown end
}




defaultSettings.profile.cooldownSize		= 1
CoreOptionsTable.args.bar.args.cooldownSize = {
	name = "Cooldown Size",
	desc = "sizes: 9, 10, 12, 13, 14, 16, 20",
	type = "range",
	order	= 13,
	min		= 1,
	max		= 7,
	step	= 1,
	set = function(info,val) 
		P.cooldownSize = val
		
		core:ResetCooldownSize()
		core:ResetAllPlateIcons()
		core:ResetIconSizes()--Adjust the frame height with the new cooldown size
		core:UpdateBarsSize()
		core:ShowAllKnownSpells()
	end,
	get = function(info) return P.cooldownSize end
}

--[[
defaultSettings.profile.cooldownSize		= "SystemFont_Tiny"
CoreOptionsTable.args.bar.args.cooldownSize = {
	name = "Cooldown size",
	order = 13,
	desc = "Size of the cooldown text",
	type = "select",
	
	values = function()
		return {
			["SystemFont_Tiny"] = "Tiny", --9
			["SystemFont_Small"] = "Small", --10
			["SystemFont_Med1"] = "Medium", --12
--~ 			["SystemFont_Med2"] = "", --13
			["SystemFont_Med3"] = "Medium2", --14
			["SystemFont_Large"] = "Large", --16
			["SystemFont_Huge1"] = "Huge", --20
		}
	end,
	set = function(info,val) 
		P.cooldownSize = val
		core:ResetCooldownSize()
		core:ResetAllPlateIcons()
		core:ResetIconSizes()--Adjust the frame height with the new cooldown size
		core:UpdateBarsSize()
	end,
	get = function(info) return P.cooldownSize end
}
]]


--testing stuff
CoreOptionsTable.args.bar.args.showBarBackground = {
	name = "Show bar background",
	desc = "Show the area where spell icons will be. This is to help you configure the bars.\nThis option won't get saved at logout.",
	type = "toggle",
	order	= 99,
	set = function(info,val) 
		core.showBarBackground = val
		core:UpdateBarsBackground()
	end,
	get = function(info) return core.showBarBackground end
}

CoreOptionsTable.args.bar.args.iconTestMode = {
	name = "Test Mode",
	desc = "For each spell on someone, multiply it by the number of Icons Per Row.\nThis option won't get saved at logout.",
	type = "toggle",
	order	= 100,
	set = function(info,val) 
		core.iconTestMode = val
	end,
	get = function(info) return core.iconTestMode end
}

-- END OF BAR



core.CoreOptionsTable = CoreOptionsTable